# z80
Z80 Simulator

This is an attempt to develop a fast and flexible Z80 CPU simulator suitable
for precise simulation of ZX Spectrum ULA logic and other timing-sensitive
hardware.

It is currently in its early development phase.

Any notes on overall design, improving performance and testing approaches are
highly appreciated.

[![Build Status](https://travis-ci.org/kosarev/z80.svg?branch=master)](https://travis-ci.org/kosarev/z80)
